@@ -215,7 +215,8 @@ class PropertyAdderBot(ABC):
                 new_claim = original_claim = extra_prop_data.claim
                 if new_claim.type == "url" and self.config.auto_dearchivify_urls:
                     de_archivify_url_property(
-                        new_claim, deprecate=self.config.auto_deprecate_archified_urls
+                        extra_prop_data,
+                        deprecate=self.config.auto_deprecate_archified_urls,
                     )
                 if property_id not in item.claims:
                     if self.can_add_main_property(
@@ -256,8 +257,8 @@ class PropertyAdderBot(ABC):
                                 acted = True
                                 break
                     else:
-                        if extra_prop_data.skip_if_conflicting_language_exists and prop in item.claims:  # type: ignore
-                            for existing_claim in item.claims[prop]:  # type: ignore
+                        if extra_prop_data.skip_if_conflicting_language_exists and property_id in item.claims:  # type: ignore
+                            for existing_claim in item.claims[property_id]:  # type: ignore
                                 existing_claim: pywikibot.Claim
                                 if isinstance(
                                     existing_claim.getTarget(),
